@@ -159,12 +159,8 @@ pyg_pointer_new(GType pointer_type, gpointer pointer)
 
     tp = g_type_get_qdata(pointer_type, pygpointer_class_key);
 
-    if (tp == NULL) {
+    if (!tp)
         tp = (PyTypeObject *)pygi_type_import_by_g_type(pointer_type);
-        if (tp == NULL) {
-            PyErr_Clear();
-        }
-    }
 
     if (!tp)
 	tp = (PyTypeObject *)&PyGPointer_Type; /* fallback */
