@@ -21,8 +21,7 @@ else:
 common.importModules(buildDir=buildDir,
                      srcDir=srcDir)
 
-SKIP_FILES = ['common', 'runtests',
-              'test_enum', 'test_conversion']
+SKIP_FILES = ['common', 'runtests']
 
 dir = os.path.split(os.path.abspath(__file__))[0]
 os.chdir(dir)
@@ -38,8 +37,8 @@ loader = unittest.TestLoader()
 
 for name in gettestnames():
     if program and program not in name:
-       continue
+        continue
     suite.addTest(loader.loadTestsFromName(name))
-    
+
 testRunner = unittest.TextTestRunner()
 testRunner.run(suite)
